@@ -67,11 +67,10 @@ def display_results(df, *args, w_mat=None, title='', palette=None, figsize=(16,
     ma.plot_perf(logy=True, title=title, y=list(args), ax=ax, c='k', lw=2)
 
 
-def display_weight_results(df, *args, w_mat=None, title='', palette=None, figsize=(16, 16),strats=None):
-    N = df.columns.size - len(args)
+def display_weight_results(w_mat=None, title='', palette=None, figsize=(16, 16)):
+    N = w_mat.columns.size
     if palette is None:
         palette = rand_color_palette(N)
-
     if w_mat is None:
         f, ax = plt.subplots(1, 1, figsize=figsize)
         print('no weights given')
