@@ -530,7 +530,7 @@ def compute_sharpe(df_ret = None, weights = None, period = 252):
     assert df_ret.shape == weights.shape
     assert sum(weights.columns == df_ret.columns) == weights.shape[1]
     portfolio = np.cumprod(np.prod(df_ret * weights.values + 1, axis=1))
-    return sharpe(portfolio ,period = period)
+    return sharpe(portfolio ,period = period), portfolio
 
 
 def f_sharpe_weights_mix(w_list_, data_, w):
